# generalvector
Simple immutable vectors.

This package and 6 other make up [ManderaGeneral](https://github.com/ManderaGeneral).

## Information
| Package                                                          | Ver                                               | Latest Release       | Python                                                                                                                   | Platform        |   Lvl | Todo                                                      | Tests   |
|:-----------------------------------------------------------------|:--------------------------------------------------|:---------------------|:-------------------------------------------------------------------------------------------------------------------------|:----------------|------:|:----------------------------------------------------------|:--------|
| [generalvector](https://github.com/ManderaGeneral/generalvector) | [1.5.15](https://pypi.org/project/generalvector/) | 2021-11-29 19:12 CET | [3.8](https://www.python.org/downloads/release/python-380/), [3.9](https://www.python.org/downloads/release/python-390/) | Windows, Ubuntu |     1 | [1](https://github.com/ManderaGeneral/generalvector#Todo) | 100.0 % |

## Contents
<pre>
<a href='#generalvector'>generalvector</a>
├─ <a href='#Information'>Information</a>
├─ <a href='#Contents'>Contents</a>
├─ <a href='#Installation'>Installation</a>
├─ <a href='#Attributes'>Attributes</a>
└─ <a href='#Todo'>Todo</a>
</pre>

## Installation
| Command                     | <a href='https://pypi.org/project/generallibrary'>generallibrary</a>   |
|:----------------------------|:-----------------------------------------------------------------------|
| `pip install generalvector` | Yes                                                                    |

## Attributes
<pre>
<a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/__init__.py#L1'>Module: generalvector</a>
├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Class: Vec</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: clamp</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: distance</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: hex</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: inrange</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: length</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: max</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: min</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: normalized</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: random</a>
│  ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: range</a>
│  └─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector.py#L1'>Method: round</a>
└─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Class: Vec2</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: clamp</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: distance</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: inrange</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: length</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: max</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: min</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: normalized</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: random</a>
   ├─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: range</a>
   └─ <a href='https://github.com/ManderaGeneral/generalvector/blob/1051f0a/generalvector/vector2.py#L1'>Method: round</a>
</pre>

## Todo
| Module                                                                                                           | Message                                                                                                                                    |
|:-----------------------------------------------------------------------------------------------------------------|:-------------------------------------------------------------------------------------------------------------------------------------------|
| <a href='https://github.com/ManderaGeneral/generalvector/blob/master/generalvector/general.py#L1'>general.py</a> | <a href='https://github.com/ManderaGeneral/generalvector/blob/master/generalvector/general.py#L7'>Move most methods to _GeneralVector.</a> |

<sup>
Generated 2021-11-29 19:12 CET for commit <a href='https://github.com/ManderaGeneral/generalvector/commit/1051f0a'>1051f0a</a>.
</sup>
